PresenceDB User Reference

## **User**

::: presencedb.user.User

## **UserStats**

::: presencedb.user.UserStats

## **CurrentActivity**

::: presencedb.user.CurrentActivity

## **AvatarHistory**

::: presencedb.user.AvatarHistory

## **ActivityRecord**

::: presencedb.user.ActivityRecord

## **Record**

::: presencedb.user.Record
